@@ -25,19 +25,9 @@ from pybuilder.core import Logger
 from pybuilder.errors import PythonbuilderException
 from pybuilder.execution import ExecutionManager
 from pybuilder.reactor import Reactor
-from pybuilder.terminal import (BOLD,
-                                BROWN,
-                                RED,
-                                GREEN,
-                                bold,
-                                styled_text,
-                                fg,
-                                italic,
-                                print_text,
-                                print_text_line,
-                                print_error,
-                                print_error_line,
-                                draw_line)
+from pybuilder.terminal import (BOLD, BROWN, RED, GREEN, bold, styled_text,
+                                fg, italic, print_text, print_text_line,
+                                print_error, print_error_line, draw_line)
 from pybuilder.utils import format_timestamp
 
 PROPERTY_OVERRIDE_PATTERN = re.compile(r'^[a-zA-Z0-9_]+=.*')
