@@ -17,9 +17,11 @@
 import imp
 import os.path
 
-from pybuilder.core import (
-    TASK_ATTRIBUTE, DEPENDS_ATTRIBUTE, DESCRIPTION_ATTRIBUTE, AFTER_ATTRIBUTE, BEFORE_ATTRIBUTE,
-    INITIALIZER_ATTRIBUTE, ACTION_ATTRIBUTE, ONLY_ONCE_ATTRIBUTE, Project, NAME_ATTRIBUTE, ENVIRONMENTS_ATTRIBUTE)
+from pybuilder.core import (TASK_ATTRIBUTE, DEPENDS_ATTRIBUTE,
+                            DESCRIPTION_ATTRIBUTE, AFTER_ATTRIBUTE,
+                            BEFORE_ATTRIBUTE, INITIALIZER_ATTRIBUTE,
+                            ACTION_ATTRIBUTE, ONLY_ONCE_ATTRIBUTE,
+                            Project, NAME_ATTRIBUTE, ENVIRONMENTS_ATTRIBUTE)
 from pybuilder.errors import PythonbuilderException, ProjectValidationFailedException
 from pybuilder.pluginloader import (BuiltinPluginLoader,
                                     DispatchingPluginLoader,
